@@ -5,5 +5,5 @@ pub use object::ObjectAccessExt;
 mod reference;
 pub use reference::ReferenceAccessExt;
 
-mod config;
-pub use config::ConfigAccessExt;
+mod repository;
+pub use repository::RepositoryAccessExt;
